package org.dromara.ems.base.service;

import org.dromara.ems.base.domain.EmsBaseEnergyType;

import java.util.List;

/**
 * 能源类型信息Service接口
 * 
 * @author Yinq
 * @date 2024-05-08
 */
public interface IEmsBaseEnergyTypeService 
{
    /**
     * 查询能源类型信息
     * 
     * @param objId 能源类型信息主键
     * @return 能源类型信息
     */
    public EmsBaseEnergyType selectEmsBaseEnergyTypeByObjId(Long objId);

    /**
     * 查询能源类型信息列表
     * 
     * @param emsBaseEnergyType 能源类型信息
     * @return 能源类型信息集合
     */
    public List<EmsBaseEnergyType> selectEmsBaseEnergyTypeList(EmsBaseEnergyType emsBaseEnergyType);

    /**
     * 新增能源类型信息
     * 
     * @param emsBaseEnergyType 能源类型信息
     * @return 结果
     */
    public int insertEmsBaseEnergyType(EmsBaseEnergyType emsBaseEnergyType);

    /**
     * 修改能源类型信息
     * 
     * @param emsBaseEnergyType 能源类型信息
     * @return 结果
     */
    public int updateEmsBaseEnergyType(EmsBaseEnergyType emsBaseEnergyType);

    /**
     * 批量删除能源类型信息
     * 
     * @param objIds 需要删除的能源类型信息主键集合
     * @return 结果
     */
    public int deleteEmsBaseEnergyTypeByObjIds(Long[] objIds);

    /**
     * 删除能源类型信息信息
     * 
     * @param objId 能源类型信息主键
     * @return 结果
     */
    public int deleteEmsBaseEnergyTypeByObjId(Long objId);

    /**
     * 根据能源类型id查询能源类型名称
     * @param energyTypeId
     * @return
     */
    String queryEnergyNameByEnergyTypeId(int energyTypeId);
}
